==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/PrometheusSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PrometheusSpecFluent<A extends PrometheusSpecFluent<A>> extends Fluent<A>{


    public A addToMetrics(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public A setToMetrics(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public A addToMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... items);
    public A addAllToMetrics(Collection<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> items);
    public A removeFromMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... items);
    public A removeAllFromMetrics(Collection<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> items);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> getMetrics();
    public List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> buildMetrics();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildMetric(int index);
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildFirstMetric();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildLastMetric();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    public A withMetrics(List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> metrics);
    public A withMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... metrics);
    public Boolean hasMetrics();
    public PrometheusSpecFluent.MetricsNested<A> addNewMetric();
    public PrometheusSpecFluent.MetricsNested<A> addNewMetricLike(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public PrometheusSpecFluent.MetricsNested<A> setNewMetricLike(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public PrometheusSpecFluent.MetricsNested<A> editMetric(int index);
    public PrometheusSpecFluent.MetricsNested<A> editFirstMetric();
    public PrometheusSpecFluent.MetricsNested<A> editLastMetric();
    public PrometheusSpecFluent.MetricsNested<A> editMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetricsExpirationPolicy instead.
 * @return The buildable object.
 */
@Deprecated public MetricsExpirationPolicy getMetricsExpirationPolicy();
    public MetricsExpirationPolicy buildMetricsExpirationPolicy();
    public A withMetricsExpirationPolicy(MetricsExpirationPolicy metricsExpirationPolicy);
    public Boolean hasMetricsExpirationPolicy();
    public A withNewMetricsExpirationPolicy(Long expiryCheckIntervalDuration,Long metricsExpiryDuration);
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> withNewMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> withNewMetricsExpirationPolicyLike(MetricsExpirationPolicy item);
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editOrNewMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editOrNewMetricsExpirationPolicyLike(MetricsExpirationPolicy item);

    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoFluent<PrometheusSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface MetricsExpirationPolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricsExpirationPolicyFluent<PrometheusSpecFluent.MetricsExpirationPolicyNested<N>>{

        
    public N and();    public N endMetricsExpirationPolicy();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/PrometheusSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PrometheusSpecFluent<A extends PrometheusSpecFluent<A>> extends Fluent<A>{


    public A addToMetrics(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public A setToMetrics(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public A addToMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... items);
    public A addAllToMetrics(Collection<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> items);
    public A removeFromMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... items);
    public A removeAllFromMetrics(Collection<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> items);
    public A removeMatchingFromMetrics(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> getMetrics();
    public List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> buildMetrics();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildMetric(int index);
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildFirstMetric();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildLastMetric();
    public me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo buildMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    public Boolean hasMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    public A withMetrics(List<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo> metrics);
    public A withMetrics(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo... metrics);
    public Boolean hasMetrics();
    public PrometheusSpecFluent.MetricsNested<A> addNewMetric();
    public PrometheusSpecFluent.MetricsNested<A> addNewMetricLike(me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public PrometheusSpecFluent.MetricsNested<A> setNewMetricLike(int index,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfo item);
    public PrometheusSpecFluent.MetricsNested<A> editMetric(int index);
    public PrometheusSpecFluent.MetricsNested<A> editFirstMetric();
    public PrometheusSpecFluent.MetricsNested<A> editLastMetric();
    public PrometheusSpecFluent.MetricsNested<A> editMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetricsExpirationPolicy instead.
 * @return The buildable object.
 */
@Deprecated public MetricsExpirationPolicy getMetricsExpirationPolicy();
    public MetricsExpirationPolicy buildMetricsExpirationPolicy();
    public A withMetricsExpirationPolicy(MetricsExpirationPolicy metricsExpirationPolicy);
    public Boolean hasMetricsExpirationPolicy();
    public A withNewMetricsExpirationPolicy(Integer expiryCheckIntervalDuration,Integer metricsExpiryDuration);
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> withNewMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> withNewMetricsExpirationPolicyLike(MetricsExpirationPolicy item);
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editOrNewMetricsExpirationPolicy();
    public PrometheusSpecFluent.MetricsExpirationPolicyNested<A> editOrNewMetricsExpirationPolicyLike(MetricsExpirationPolicy item);

    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoFluent<PrometheusSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface MetricsExpirationPolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricsExpirationPolicyFluent<PrometheusSpecFluent.MetricsExpirationPolicyNested<N>>{

        
    public N and();    public N endMetricsExpirationPolicy();
}


}
